import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';
import 'package:sghi_core/afya_moja_core/src/domain/core/entities/coordinates.dart';
import 'package:sghi_core/afya_moja_core/src/domain/core/entities/facility_identifier.dart';

part 'facility.freezed.dart';
part 'facility.g.dart';

@freezed
class Facility with _$Facility {
  factory Facility({
    @JsonKey(name: 'id') String? id,
    @JsonKey(name: 'name') String? name,
    @JsonKey(name: 'description') String? description,
    @JsonKey(name: 'type') String? type,
    @JsonKey(name: 'county') String? county,
    @JsonKey(name: 'country') String? country,
    @JsonKey(name: 'address') String? address,
    @JsonKey(name: 'coordinates') Coordinates? coordinates,
    @JsonKey(name: 'phone') String? phone,
    @JsonKey(name: 'active', defaultValue: false) bool? active,
    @JsonKey(name: 'identifier') FacilityIdentifier? facilityIdentifier,
    @JsonKey(name: 'identifiers')
    List<FacilityIdentifier?>? facilityIdentifiers,
    @JsonKey(name: 'fhirOrganisationID') String? fhirOrganisationID,
    @JsonKey(name: 'workStationDetails') WorkStationDetails? workStationDetails,
    @JsonKey(name: 'contacts') List<Contact?>? contacts,
  }) = _Facility;

  factory Facility.fromJson(Map<String, dynamic> json) =>
      _$FacilityFromJson(json);

  factory Facility.initial() => Facility(
        id: UNKNOWN,
        name: UNKNOWN,
        phone: UNKNOWN,
        active: false,
        country: UNKNOWN,
        facilityIdentifier: FacilityIdentifier.initial(),
        description: UNKNOWN,
        fhirOrganisationID: UNKNOWN,
        workStationDetails: WorkStationDetails.initial(),
        facilityIdentifiers: <FacilityIdentifier>[],
        address: UNKNOWN,
        contacts: <Contact>[],
        coordinates: Coordinates.initial(),
        county: UNKNOWN,
        type: UNKNOWN,
      );
}
