import 'package:flutter/material.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';
import 'package:sghi_core/afya_moja_core/src/app_strings.dart';
import 'package:sghi_core/afya_moja_core/src/domain/value_objects/dummy_data.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/facility/custom_chip.dart';
import 'package:sghi_core/afya_moja_core/src/widget_keys.dart';

class FilterBottomSheet extends StatelessWidget {
  const FilterBottomSheet({super.key, required this.onFilterCallBack});

  final Function(dynamic filters) onFilterCallBack;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(20.0),
      child: SingleChildScrollView(
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Row(
              children: <Widget>[
                InkWell(
                  key: closeBottomSheetKey,
                  onTap: () {
                    Navigator.of(context).pop();
                  },
                  child: Container(
                    padding: const EdgeInsets.all(10),
                    decoration: BoxDecoration(
                      color: primaryColor.withOpacity(.4),
                      borderRadius: BorderRadius.circular(50),
                    ),
                    child: const Icon(Icons.close, color: primaryColor),
                  ),
                ),
                smallHorizontalSizedBox,
                Text(filterFacilities, style: normalSize18Text(blackColor)),
              ],
            ),
            mediumVerticalSizedBox,
            Text(servicesOfferedTitle, style: boldSize16Text(blackColor)),
            smallVerticalSizedBox,
            Text(
              servicesOfferedFacility,
              style: normalSize16Text(greyTextColor),
            ),
            mediumVerticalSizedBox,
            const Wrap(
              alignment: WrapAlignment.spaceBetween,
              spacing: 15,
              runSpacing: 15,
              children: <Widget>[
                CustomChip(
                  title: htsString,
                  backgroundColor: darkGreyBackgroundColor,
                ),
                CustomChip(
                  title: prepString,
                  backgroundColor: primaryColor,
                  textColor: whiteColor,
                ),
                CustomChip(
                  title: artString,
                  backgroundColor: darkGreyBackgroundColor,
                ),
                CustomChip(
                  title: selfTestingString,
                  backgroundColor: darkGreyBackgroundColor,
                ),
              ],
            ),
            largeVerticalSizedBox,
            Text(
              locationString,
              style: boldSize16Text(blackColor),
            ),
            smallVerticalSizedBox,
            Text(
              facilityLocationDescription,
              style: normalSize16Text(greyTextColor),
            ),
            mediumVerticalSizedBox,
            const Wrap(
              alignment: WrapAlignment.spaceBetween,
              spacing: 15,
              runSpacing: 15,
              children: <Widget>[
                CustomChip(
                  title: nearMeString,
                  backgroundColor: darkGreyBackgroundColor,
                ),
                CustomChip(
                  title: oneKmString,
                  backgroundColor: primaryColor,
                  textColor: whiteColor,
                ),
                CustomChip(
                  title: twoKmString,
                  backgroundColor: darkGreyBackgroundColor,
                ),
                CustomChip(
                  title: fiveKmString,
                  backgroundColor: darkGreyBackgroundColor,
                ),
              ],
            ),
            largeVerticalSizedBox,
            SizedBox(
              width: double.infinity,
              child: MyAfyaHubPrimaryButton(
                buttonColor: primaryColor,
                text: applyFilters,
                customRadius: 8,
                borderColor: Colors.transparent,
                customPadding: const EdgeInsets.all(14),
                onPressed: () {
                  onFilterCallBack.call(<String, dynamic>{});
                },
              ),
            ),
            mediumVerticalSizedBox,
          ],
        ),
      ),
    );
  }
}
